##  Resources
Ready to define your organization's tech categories? Use the following reference documents to set up an IT Component Landscape quickly and get into use cases like Standards Management or Technology Obsolescence Management:
  * [Best Practices to Define Tech Categories![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fbest-practices-to-define-technology-stacks "https://www.leanix.net/en/download/best-practices-to-define-technology-stacks")- Learn how to get started with tech categories to create a complete overview of your technology landscape.
  * [Tech Categories in the Reference Catalog](https://help.sap.com/docs/leanix/ea/tech-categories-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Tech categories in the reference catalog enable you to adopt the Technology Business Management \(TBM\) Taxonomy.")- Learn how to import tech categories information from the reference catalog and adapt this taxonomy.


YesNo
Send
